@@ -336,7 +336,7 @@ class Schema:
             if not schemaItem: 
                 return item
             item["defindex"] = schemaItem["defindex"]
-            item["quality"] = item["quality"] or schemaItem["item_quality"] # default quality
+            item["quality"] = item.get("quality") or schemaItem.get("item_quality") # default quality
             return item
 
         wears = {
@@ -435,7 +435,7 @@ class Schema:
                     continue
                 if qualitySearch.startswith(quality):
                     name = name.replace(quality, "").strip()
-                    item["quality2"] = item["quality2"] or item["quality"]
+                    item["quality2"] = item.get("quality2") or item.get("quality")
                     item["quality"] = self.qualities[qualityC]
                     break
 
@@ -496,7 +496,7 @@ class Schema:
                         item["quality"] = 5
                 elif item["quality"] != 5:
                     # will set quality to unusual if undefined, or make it primary, it other quality exists
-                    item["quality2"] = item.get("quality2") or item["quality"]
+                    item["quality2"] = item.get("quality2") or item.get("quality")
                     item["quality"] = 5
                 break
 
@@ -574,7 +574,7 @@ class Schema:
                 schemaItem = self.getItemByItemName(name)
                 if not schemaItem: return item
                 item["target"] = schemaItem["defindex"]
-                item["quality"] = item["quality"] or schemaItem["item_quality"] # default quality
+                item["quality"] = item.get("quality") or schemaItem.get("item_quality") # default quality
             if not item.get("quality"): item["quality"] = 6
             item["output"] = 6526 if item["killstreak"] > 2 else 6523
             item["outputQuality"] = 6
@@ -586,7 +586,7 @@ class Schema:
             if not schemaItem: return item
             item["output"] = schemaItem["defindex"]
             item["outputQuality"] = 14
-            item["quality"] = item["quality"] or schemaItem["item_quality"] # default quality
+            item["quality"] = item.get("quality") or schemaItem.get("item_quality") # default quality
 
         if "strangifier chemistry set" in name:
             name = name.replace("strangifier chemisty set", "").strip()
@@ -606,7 +606,7 @@ class Schema:
             schemaItem = self.getItemByItemName(name)
             if not schemaItem: return name
             item["target"] = schemaItem["defindex"]
-            item["quality"] = item["quality"] or schemaItem["quality"] # default quality
+            item["quality"] = item.get("quality") or schemaItem.get("quality") # default quality
 
         if "kit" in name and item.get("killstreak"):
             name = name.replace("kit", "").strip()
@@ -672,13 +672,13 @@ class Schema:
                 for retiredKey in retiredKeys:
                     if retiredKey['name'].lower() == name:
                         item["defindex"] = retiredKey["defindex"]
-                        item["quality"] = item["quality"] or 6
+                        item["quality"] = item.get["quality"] or 6
                         return item
 
             schemaItem = self.getItemByNameWithThe(name)
             if not schemaItem: return item
             item["defindex"] = schemaItem["defindex"]
-            item["quality"] = item["quality"] or schemaItem["item_quality"] # default quality
+            item["quality"] = item.get("quality") or schemaItem.get("item_quality") # default quality
 
             # Fix defindex for Exclusive Genuine items
             if item["quality"] == 1:
